@@ -16,6 +16,7 @@ import lfs.core.utils
 import lfs.order.utils
 import lfs.payment.utils
 import lfs.shipping.utils
+import lfs.voucher.utils
 from lfs.cart import utils as cart_utils
 from lfs.checkout.forms import OnePageCheckoutForm
 from lfs.checkout.settings import CHECKOUT_TYPE_ANON
@@ -29,6 +30,7 @@ from lfs.payment.settings import PAYPAL
 from lfs.payment.settings import DIRECT_DEBIT
 from lfs.payment.settings import CREDIT_CARD
 from lfs.voucher.models import Voucher
+from lfs.voucher.settings import MESSAGES
 
 def login(request, template_name="lfs/checkout/login.html"):
     """Displays a form to login or register/login the user within the check out
@@ -127,19 +129,27 @@ def cart_inline(request, template_name="lfs/checkout/checkout_cart_inline.html")
     cart_price = cart_costs["price"] + shipping_costs["price"] + payment_costs["price"]
     cart_tax = cart_costs["tax"] + shipping_costs["tax"] + payment_costs["tax"]
 
-    # Voucer
+    # Voucher
     try:
-        voucher = Voucher.objects.get(number=request.POST.get("voucher"))
+        voucher_number = lfs.voucher.utils.get_current_voucher_number(request)
+        voucher = Voucher.objects.get(number=voucher_number)
     except Voucher.DoesNotExist:
         display_voucher = False
         voucher_value = 0
         voucher_tax = 0
-    else:        
-        display_voucher = True
-        voucher_value = voucher.get_price_gross(cart)
-        cart_price = cart_price - voucher_value
-        voucher_tax = voucher.get_tax(cart)
-        voucher.mark_as_used()
+        voucher_message = MESSAGES[6]
+    else:
+        lfs.voucher.utils.set_current_voucher_number(request, voucher_number)
+        is_voucher_effective, voucher_message = voucher.is_effective(cart)
+        if is_voucher_effective:
+            display_voucher = True
+            voucher_value = voucher.get_price_gross(cart)
+            cart_price = cart_price - voucher_value
+            voucher_tax = voucher.get_tax(cart)
+        else:
+            display_voucher = False
+            voucher_value = 0
+            voucher_tax = 0
 
     return render_to_string(template_name, RequestContext(request, {
         "cart" : cart,
@@ -152,6 +162,8 @@ def cart_inline(request, template_name="lfs/checkout/checkout_cart_inline.html")
         "payment_price" : payment_costs["price"],
         "selected_shipping_method" : selected_shipping_method,
         "selected_payment_method" : selected_payment_method,
+        "voucher_number" : voucher_number,
+        "voucher_message" : voucher_message,
     }))
 
 def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
@@ -265,28 +277,28 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
             # Create or update invoice address
             if customer.selected_invoice_address is None:
                 invoice_address = Address.objects.create(
-                    firstname = form.data.get("invoice_firstname"),
-                    lastname = form.data.get("invoice_lastname"),
-                    company_name = form.data.get("invoice_company_name"),
-                    street = form.data.get("invoice_street"),
-                    zip_code = form.data.get("invoice_zip_code"),
-                    city = form.data.get("invoice_city"),
-                    country_id = form.data.get("invoice_country"),
-                    phone = form.data.get("invoice_phone"),
-                    email = form.data.get("invoice_email"),
+                    firstname = form.data.get("invoice_firstname", ""),
+                    lastname = form.data.get("invoice_lastname", ""),
+                    company_name = form.data.get("invoice_company_name", ""),
+                    street = form.data.get("invoice_street", ""),
+                    zip_code = form.data.get("invoice_zip_code", ""),
+                    city = form.data.get("invoice_city", ""),
+                    country_id = form.data.get("invoice_country", ""),
+                    phone = form.data.get("invoice_phone", ""),
+                    email = form.data.get("invoice_email", ""),
                 )
                 customer.selected_invoice_address = invoice_address
             else:
                 selected_invoice_address = customer.selected_invoice_address
-                selected_invoice_address.firstname = form.data.get("invoice_firstname")
-                selected_invoice_address.lastname = form.data.get("invoice_lastname")
-                selected_invoice_address.company_name = form.data.get("invoice_company_name")
-                selected_invoice_address.street = form.data.get("invoice_street")
-                selected_invoice_address.zip_code = form.data.get("invoice_zip_code")
-                selected_invoice_address.city = form.data.get("invoice_city")
-                selected_invoice_address.country_id = form.data.get("invoice_country")
-                selected_invoice_address.phone = form.data.get("invoice_phone")
-                selected_invoice_address.email = form.data.get("invoice_email")
+                selected_invoice_address.firstname = form.data.get("invoice_firstname", "")
+                selected_invoice_address.lastname = form.data.get("invoice_lastname", "")
+                selected_invoice_address.company_name = form.data.get("invoice_company_name", "")
+                selected_invoice_address.street = form.data.get("invoice_street", "")
+                selected_invoice_address.zip_code = form.data.get("invoice_zip_code", "")
+                selected_invoice_address.city = form.data.get("invoice_city", "")
+                selected_invoice_address.country_id = form.data.get("invoice_country", "")
+                selected_invoice_address.phone = form.data.get("invoice_phone", "")
+                selected_invoice_address.email = form.data.get("invoice_email", "")
                 selected_invoice_address.save()
 
             # If the shipping address differs from invoice firstname we create
@@ -364,8 +376,9 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
 
         # Set the addresses country to the current selected in any case.
         country = lfs.shipping.utils.get_selected_shipping_country(request)
-        initial["shipping_country"] = country.id
-        initial["invoice_country"] = country.id
+        if country:
+            initial["shipping_country"] = country.id
+            initial["invoice_country"] = country.id
         form = checkout_form(initial=initial)
 
     cart = cart_utils.get_cart(request)
@@ -393,6 +406,7 @@ def one_page_checkout(request, checkout_form = OnePageCheckoutForm,
         "selected_payment_method" : selected_payment_method,
         "display_bank_account" : display_bank_account,
         "display_credit_card" : display_credit_card,
+        "voucher_number" : lfs.voucher.utils.get_current_voucher_number(request),
     }))
 
     if form._errors:
@@ -459,6 +473,9 @@ def shipping_inline(request, template_name="lfs/checkout/shipping_inline.html"):
 def check_voucher(request):
     """
     """
+    voucher_number = lfs.voucher.utils.get_current_voucher_number(request)
+    lfs.voucher.utils.set_current_voucher_number(request, voucher_number)
+
     result = simplejson.dumps({
         "html" : (("#cart-inline", cart_inline(request)),)
     })
