@@ -49,22 +49,22 @@ class Order(models.Model):
 
     invoice_firstname = models.CharField(_(u"Invoice firstname"), max_length=50)
     invoice_lastname = models.CharField(_(u"Invoice lastname"), max_length=50)
-    invoice_company_name = models.CharField(_(u"Invoice company name"), max_length=50)
+    invoice_company_name = models.CharField(_(u"Invoice company name"), max_length=50, blank=True)
     invoice_street = models.CharField(_(u"Invoice street"), blank=True, max_length=100)
     invoice_zip_code = models.CharField(_(u"Invoice zip code"), max_length=10)
     invoice_city = models.CharField(_(u"Invoice city"), max_length=50)
     invoice_state = models.CharField(_(u"Invoice state"), max_length=50)
-    invoice_country = models.ForeignKey(Country, related_name="orders_invoice_country")
+    invoice_country = models.ForeignKey(Country, related_name="orders_invoice_country", blank=True, null=True)
     invoice_phone = models.CharField(_(u"Invoice phone"), blank=True, max_length=20)
 
     shipping_firstname = models.CharField(_(u"Shipping firstname"), max_length=50)
     shipping_lastname = models.CharField(_(u"Shipping lastname"), max_length=50)
-    shipping_company_name = models.CharField(_(u"Shipping company name"), max_length=50)
+    shipping_company_name = models.CharField(_(u"Shipping company name"), max_length=50, blank=True)
     shipping_street = models.CharField(_(u"Shipping street"), blank=True, max_length=100)
     shipping_zip_code = models.CharField(_(u"Shipping zip code"), max_length=10)
     shipping_city = models.CharField(_(u"Shipping city"), max_length=50)
     shipping_state = models.CharField(_(u"Shipping state"), max_length=50)
-    shipping_country = models.ForeignKey(Country, related_name="orders_shipping_country")
+    shipping_country = models.ForeignKey(Country, related_name="orders_shipping_country", blank=True, null=True)
     shipping_phone = models.CharField(_(u"Shipping phone"), blank=True, max_length=20)
 
     shipping_method = models.ForeignKey(ShippingMethod, verbose_name=_(u"Shipping Method"), blank=True, null=True)
