@@ -1,4 +1,5 @@
 # lfs imports
+import lfs.voucher.utils
 from lfs.cart import utils as cart_utils
 from lfs.core.signals import order_submitted
 from lfs.customer import utils as customer_utils
@@ -54,16 +55,21 @@ def add_order(request):
 
     # Add voucher if one exists
     try:
-        voucher = Voucher.objects.get(number=request.POST.get("voucher"))
+        voucher_number = lfs.voucher.utils.get_current_voucher_number(request)
+        voucher = Voucher.objects.get(number=voucher_number)
     except Voucher.DoesNotExist:
         voucher = None
     else:
-        voucher_number = voucher.number
-        voucher_price = voucher.get_price_gross(cart)
-        voucher_tax = voucher.get_tax(cart)
+        is_voucher_effective, voucher_message = voucher.is_effective(cart)
+        if is_voucher_effective:
+            voucher_number = voucher.number
+            voucher_price = voucher.get_price_gross(cart)
+            voucher_tax = voucher.get_tax(cart)
 
-        price -= voucher_price
-        tax -= voucher_tax
+            price -= voucher_price
+            tax -= voucher_tax
+        else:
+            voucher = None
 
     order = Order.objects.create(
         user = user,
@@ -104,6 +110,7 @@ def add_order(request):
     )
 
     if voucher:
+        voucher.mark_as_used()
         order.voucher_number = voucher_number
         order.voucher_price = voucher_price
         order.voucher_tax = voucher_tax
@@ -140,7 +147,7 @@ def add_order(request):
         cart_item.product.decrease_stock_amount(cart_item.amount)
 
     cart.delete()
-    order_submitted.send(order)
+    order_submitted.send({"order" : order, "request" : request})
 
     # Note: Save order for later use in thank you page. The order will be
     # removed from the session if the thank you page has been called.
